//	FileLoader.h - Loads and saves from/to X3D files.
//	----------------------------------------------------------------------------
//	This file is part of Motion Composition Tool, a simple application for
//	creating simple abstract animations.
//	Copyright (c) 2007 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#ifndef FILELOADER_H_
#define FILELOADER_H_

#include "juce.h"

class Window;

///	Loads and saves from/to X3D files.
class FileLoader : public FileBasedDocument
{
  public:
	///	Constructor.
	FileLoader(Window *parent);
	///	Destructor.
	~FileLoader();

	///	Returns the file's name.
	const String getDocumentTitle();
	///	Loads a file.
	const String loadDocument(const File& file);
	///	Saves a file.
	const String saveDocument(const File& file);
	///	Returns the last opened document.
	const File getLastDocumentOpened();
	///	Sets the last opened document.
	void setLastDocumentOpened(const File& file);

	juce_UseDebuggingNewOperator
  private:
	///	The owning Window.
	Window *window;
	///	The last opened document.
	File lastFile;

	static const char * const outFile1;
	static const char * const outFile2;
	static const char * const outFile3;
	static const char * const outFile4;
	static const char * const outFile5;
	static const char * const outFile6;
	static const char * const outFile7;
	static const char * const outFile8;
	static const char * const outFile9;
	static const char * const outFile10;
	static const char * const outFile11;
	static const char * const outFile12;
	static const char * const outFile13;
	static const char * const outFile14;
};

#endif
